@@ -13,7 +13,7 @@
 #' handler or Opal read/write permissions.
 #' 
 #' @seealso
-#' Please see [Opal documentation](https://opaldoc.obiba.org/en/dev/) for 
+#' Please see [Opal documentation](https://opaldoc.obiba.org/) for 
 #' complete documentation.
 #'
 #' @param opal Opal login attributes.
@@ -27,7 +27,7 @@
 #' environment.
 #'
 #' @examples
-#' {
+#' \dontrun{
 #' 
 #' library(opalr)
 #' opal <-
@@ -80,7 +80,7 @@ opal_project_create <- function(opal, project, tag = NULL){
 #' handler or Opal read/write permissions.
 #'
 #' @seealso
-#' Please see [Opal documentation](https://opaldoc.obiba.org/en/dev/) for 
+#' Please see [Opal documentation](https://opaldoc.obiba.org/) for 
 #' complete documentation.
 #'
 #' @param opal Opal login attributes.
@@ -94,7 +94,7 @@ opal_project_create <- function(opal, project, tag = NULL){
 #' The path to Opal needs to be pasted with Opal absolute path.
 #'
 #' @examples
-#' {
+#' \dontrun{
 #' 
 #' library(opalr)
 #' opal <- 
@@ -133,7 +133,7 @@ opal_files_push <- function(opal, from, to){
 #' handler or Opal read/write permissions.
 #' 
 #' @seealso
-#' Please see [Opal documentation](https://opaldoc.obiba.org/en/dev/) for 
+#' Please see [Opal documentation](https://opaldoc.obiba.org/) for 
 #' complete documentation.
 #'
 #' @param opal Opal login attributes.
@@ -146,7 +146,7 @@ opal_files_push <- function(opal, from, to){
 #' Folder(s) containing files coming from Opal in user R environment.
 #'
 #' @examples
-#' {
+#' \dontrun{
 #' 
 #' library(opalr)
 #' opal <- 
@@ -225,7 +225,7 @@ opal_files_pull <- function(opal, from, to){
 #' handler or Opal read/write permissions.
 #'
 #' @seealso
-#' Please see [Opal documentation](https://opaldoc.obiba.org/en/dev/) for 
+#' Please see [Opal documentation](https://opaldoc.obiba.org/) for 
 #' complete documentation.
 #' [madshapR::as_dossier()] 
 #' [madshapR::as_dataset()]
@@ -250,7 +250,7 @@ opal_files_pull <- function(opal, from, to){
 #' A table or table(s) in Opal.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' 
 #' library(opalr)
 #' opal <- 
@@ -415,7 +415,7 @@ opal_tables_push <- function(
 #' handler or Opal read/write permissions.
 #'
 #' @seealso
-#' Please see [Opal documentation](https://opaldoc.obiba.org/en/dev/) for 
+#' Please see [Opal documentation](https://opaldoc.obiba.org/) for 
 #' complete documentation.
 #' [madshapR::as_dossier()] 
 #' [madshapR::as_dataset()]
@@ -436,7 +436,7 @@ opal_tables_push <- function(
 #' respective data dictionary.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' 
 #' library(opalr)
 #' opal <- 
@@ -613,7 +613,7 @@ opal_tables_pull <- function(
 #' handler or Opal read/write permissions.
 #'
 #' @seealso
-#' Please see [Opal documentation](https://opaldoc.obiba.org/en/dev/) for 
+#' Please see [Opal documentation](https://opaldoc.obiba.org/) for 
 #' complete documentation.
 #' [madshapR::as_taxonomy()]
 #'
@@ -623,14 +623,14 @@ opal_tables_pull <- function(
 #' A tibble identifying a taxonomy (generally generated from Opal taxonomy.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' 
 #' library(opalr)
 #' opal <-
 #'  opal.login('administrator','password',
 #'    url ='https://opal-demo.obiba.org/')
 #' 
-#' try(taxonomy_opal_get(opal))
+#' try(taxonomy_opal_mlstr_get(opal))
 #'   
 #' }
 #'
@@ -638,7 +638,7 @@ opal_tables_pull <- function(
 #' @importFrom rlang .data
 #'
 #' @export
-taxonomy_opal_mlstr_get <- function(opal = NULL){
+taxonomy_opal_mlstr_get <- function(opal){
 
   taxonomy <- taxonomy_opal_get(opal)
 
@@ -681,8 +681,8 @@ taxonomy_opal_mlstr_get <- function(opal = NULL){
         TRUE                                                ~ NA_character_
       )) %>%
     select(
-      everything(),-.data$`vocabulary`,-.data$`vocabulary_short`,-.data$`term`,
-      .data$`vocabulary`, .data$`vocabulary_short`, .data$`term`)
+      everything(),-"vocabulary",-"vocabulary_short",-starts_with("term"),
+      "vocabulary", "vocabulary_short", starts_with("term"))
 
   list_of_scales <-
     c("Mlstr_habits",
@@ -695,10 +695,14 @@ taxonomy_opal_mlstr_get <- function(opal = NULL){
     taxonomy %>%
     filter(.data$`taxonomy` %in% list_of_scales) %>%
     select(
-      index_term_scale       = .data$`index_term`,
-      taxonomy_scale         = .data$`taxonomy`,
-      vocabulary_scale       = .data$`vocabulary`,
-      term_scale             = .data$`term`) %>%
+      index_term_scale            = "index_term",
+      taxonomy_scale              = "taxonomy",
+      taxonomy_scale_title        = "taxonomy_title",
+      taxonomy_scale_description  = "taxonomy_description",
+      vocabulary_scale            = "vocabulary",
+      term_scale                  = "term",
+      term_scale_title        = "term_title",
+      term_scale_description  = "term_description") %>%
     mutate(
       term = case_when(
         .data$`taxonomy_scale` == "Mlstr_habits"    &
@@ -820,7 +824,7 @@ taxonomy_opal_mlstr_get <- function(opal = NULL){
                .data$`index_term_scale` == 0,
                paste0("[NO_SCALE], ",.data$`term_scale`),
                .data$`term_scale`)) %>%
-    separate_rows(.data$`term_scale` ,sep = ", ") %>%
+    separate_rows("term_scale" ,sep = ", ") %>%
     mutate(across(all_of(
       c("index_term_scale","taxonomy_scale","vocabulary_scale","term_scale")),
       ~ ifelse(.data$`term_scale` == "[NO_SCALE]", NA,.))) %>%
@@ -865,7 +869,7 @@ taxonomy_opal_mlstr_get <- function(opal = NULL){
 #' handler or Opal read/write permissions.
 #'
 #' @seealso
-#' Please see [Opal documentation](https://opaldoc.obiba.org/en/dev/) for 
+#' Please see [Opal documentation](https://opaldoc.obiba.org/) for 
 #' complete documentation.
 #' [madshapR::as_taxonomy()]
 #'
@@ -875,7 +879,7 @@ taxonomy_opal_mlstr_get <- function(opal = NULL){
 #' A tibble identifying a taxonomy (generally generated from Opal taxonomy).
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' 
 #' library(opalr)
 #' opal <- 
@@ -902,14 +906,18 @@ taxonomy_opal_get <- function(opal){
       index_term = as.integer(),
       taxonomy = as.character(),
       vocabulary = as.character(),
-      term = as.character())
+      taxonomy_title = as.character(),
+      taxonomy_description = as.character(),
+      term = as.character(),
+      label = as.character())
 
     return(taxonomy)
   }
 
   taxonomy <-
     taxonomy %>%
-    select(taxonomy = 'name',  vocabulary = 'vocabularies') %>%
+    select(taxonomy = 'name',  vocabulary = 'vocabularies', 
+           taxonomy_title = 'title', taxonomy_description = 'description') %>%
     add_row(taxonomy = "Unknown_taxonomy",vocabulary = "", .before = TRUE) %>%
     add_index("index_taxonomy", start = 0) %>%
     rowwise() %>%
@@ -950,15 +958,48 @@ taxonomy_opal_get <- function(opal){
       'index_taxonomy',
       'index_vocabulary',
       'index_term',
+      starts_with('taxonomy'),
       everything())
 
   .add_qual_check <- FALSE
   if(.add_qual_check == FALSE)
     taxonomy <- taxonomy %>% filter(.data$`index_term` != 0)
+  
+  terms_labels <- 
+    tibble(term = as.character(),
+           term_title = as.character(),
+           term_description = as.character())
+  
+  distinct_vocabularies <- distinct(taxonomy[c('taxonomy','vocabulary')])
+  
+  for(i in seq_len(nrow(distinct_vocabularies))){
+    # stop()}
+    
+    message(i,'/',nrow(distinct_vocabularies),
+            " - Gather taxonomy of ",distinct_vocabularies$vocabulary[i])
+    terms_labels <- 
+      bind_rows(
+        terms_labels,
+        tibble(
+          opal.terms(
+            opal,
+            distinct_vocabularies$taxonomy[i],
+            distinct_vocabularies$vocabulary[i])) %>%
+          select(term = 'name',
+                 term_title = 'title',
+                 term_description = 'description') %>%
+          mutate(taxonomy = distinct_vocabularies$taxonomy[i],
+                 vocabulary = distinct_vocabularies$vocabulary[i]))
+  }
+  
 
+  if(nrow(terms_labels) != nrow(taxonomy)){
+    stop(call. = FALSE, "Problem in taxonomy. Please contact us.")}
+  
   taxonomy <- 
-    as_taxonomy(taxonomy) %>%
-    tibble 
+    taxonomy %>%
+    full_join(terms_labels,by = c('taxonomy', 'vocabulary', 'term')) %>%
+    as_taxonomy() 
 
   return(taxonomy)
 
@@ -981,7 +1022,7 @@ taxonomy_opal_get <- function(opal){
 #' handler or Opal read/write permissions.
 #'
 #' @seealso
-#' Please see [Opal documentation](https://opaldoc.obiba.org/en/dev/) for 
+#' Please see [Opal documentation](https://opaldoc.obiba.org/) for 
 #' complete documentation.
 #' [madshapR::as_data_dict_mlstr()]
 #'
@@ -992,7 +1033,7 @@ taxonomy_opal_get <- function(opal){
 #' A list of tibble(s) identifying a data dictionary.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' 
 #' library(opalr)
 #' opal <- 
